@@ -577,7 +577,7 @@ class Vm(object):
         concatenated in one before it is tokenized
         """
         log.debug("Enter")
-        self.ssh.shell_send(["sudo ps -xww | grep qemu-system\n"])
+        self.ssh.shell_send(["sudo ps -xww | grep -E 'qemu-system\s|kvm\s'\n"])
         self._vms_total = {}
         self._vms_total['cpu'] = 0
         self._vms_total['memory'] = 0
@@ -589,8 +589,12 @@ class Vm(object):
             log.debug("line={}".format(line))
             need_tokenize = False
             # Looking for kvm process starting line (qemu-system-x86_64)
-            if line.find('qemu-system-x86_64') != -1:
-                log.debug("Found kvm process line start")
+            if line.find('qemu-system-x86_64\s') != -1:
+                log.debug("Found kvm process form qemu-system-x86_64 line start")
+                kvm_start = True
+                kvm_end = False
+            if line.find('kvm\s') != -1:
+                log.debug("Found kvm process form kvm line start")
                 kvm_start = True
                 kvm_end = False
             # Looking for kvm process ending line (\stimestamp=on)
